@@ -1,8 +1,9 @@
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
-from vanilla.generic_views import (
+from django.views.generic import View
+from vanilla.views import (
     GenericView, RedirectView, TemplateView, FormView
 )
-from vanilla.generic_model_views import (
+from vanilla.model_views import (
     GenericModelView, ListView, DetailView, CreateView, UpdateView, DeleteView
 )
